"""
Библиотека для взаимодействия с моделями AI через API.

Основные функции:
    - ask: Отправляет запрос к модели и возвращает ответ.
    - answer: Отправляет запрос к модели и выводит ответ в консоль.

>>> from danya import ask, answer
"""

from .main import answer, ask
